@@ -111,6 +111,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -125,10 +126,10 @@ EXAMPLES = '''
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_log_ratelimit_ratelimits:
-          filter: <string>
-          filter_type: <value in [devid, adom]>
-          id: <integer>
-          ratelimit: <integer>
+          id: 0 # Required variable, integer
+          # filter: <string>
+          # filter_type: <value in [devid, adom]>
+          # ratelimit: <integer>
 '''
 
 RETURN = '''
