@@ -100,22 +100,25 @@ options:
             _gui_meta:
                 type: str
                 description: Gui meta.
-            group-name:
+            group_name:
+                aliases: ['group-name']
                 type: str
-                description: Deprecated, please rename it to group_name. Name of matching user or group on remote authentication server.
+                description: Name of matching user or group on remote authentication server.
             id:
                 type: int
                 description: ID.
                 required: true
-            server-name:
+            server_name:
+                aliases: ['server-name']
                 type: str
-                description: Deprecated, please rename it to server_name. Name of remote auth server.
+                description: Name of remote auth server.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -133,10 +136,10 @@ EXAMPLES = '''
         dynamic_mapping: <your own value>
         state: present # <value in [present, absent]>
         user_group_dynamicmapping_match:
-          _gui_meta: <string>
-          group_name: <string>
-          id: <integer>
-          server_name: <string>
+          id: 0 # Required variable, integer
+          # _gui_meta: <string>
+          # group_name: <string>
+          # server_name: <string>
 '''
 
 RETURN = '''
@@ -180,23 +183,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/group/{group}/dynamic_mapping/{dynamic_mapping}/match',
         '/pm/config/global/obj/user/group/{group}/dynamic_mapping/{dynamic_mapping}/match'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/group/{group}/dynamic_mapping/{dynamic_mapping}/match/{match}',
-        '/pm/config/global/obj/user/group/{group}/dynamic_mapping/{dynamic_mapping}/match/{match}'
-    ]
-
     url_params = ['adom', 'group', 'dynamic_mapping']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -205,14 +200,13 @@ def main():
         'dynamic_mapping': {'required': True, 'type': 'str'},
         'user_group_dynamicmapping_match': {
             'type': 'dict',
-            'v_range': [['7.0.2', '7.4.0']],
+            'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']],
             'options': {
-                '_gui_meta': {'v_range': [['7.0.2', '7.4.0']], 'type': 'str'},
-                'group-name': {'v_range': [['7.0.2', '7.4.0']], 'type': 'str'},
-                'id': {'v_range': [['7.0.2', '7.4.0']], 'required': True, 'type': 'int'},
-                'server-name': {'v_range': [['7.0.2', '7.4.0']], 'type': 'str'}
+                '_gui_meta': {'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'str'},
+                'group-name': {'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'str'},
+                'id': {'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']], 'required': True, 'type': 'int'},
+                'server-name': {'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'str'}
             }
-
         }
     }
 
@@ -221,14 +215,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'user_group_dynamicmapping_match'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
