@@ -98,11 +98,11 @@ options:
             apps:
                 type: list
                 elements: dict
-                description: No description.
+                description: Apps.
                 suboptions:
                     md5s:
                         type: raw
-                        description: (list) No description.
+                        description: (list) MD5 checksum.
                     name:
                         type: str
                         description: Name.
@@ -116,6 +116,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -131,12 +132,11 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         vpnsslweb_virtualdesktopapplist:
-          action: <value in [block, allow]>
-          apps:
-            -
-              md5s: <list or string>
-              name: <string>
-          name: <string>
+          name: "your value" # Required variable, string
+          # action: <value in [block, allow]>
+          # apps:
+          #   - md5s: <list or string>
+          #     name: <string>
 '''
 
 RETURN = '''
@@ -180,41 +180,32 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/vpn/ssl/web/virtual-desktop-app-list',
         '/pm/config/global/obj/vpn/ssl/web/virtual-desktop-app-list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/vpn/ssl/web/virtual-desktop-app-list/{virtual-desktop-app-list}',
-        '/pm/config/global/obj/vpn/ssl/web/virtual-desktop-app-list/{virtual-desktop-app-list}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'vpnsslweb_virtualdesktopapplist': {
             'type': 'dict',
-            'v_range': [['6.2.0', '6.2.12']],
+            'v_range': [['6.2.0', '6.2.13']],
             'options': {
-                'action': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['block', 'allow'], 'type': 'str'},
+                'action': {'v_range': [['6.2.0', '6.2.13']], 'choices': ['block', 'allow'], 'type': 'str'},
                 'apps': {
-                    'v_range': [['6.2.0', '6.2.12']],
+                    'v_range': [['6.2.0', '6.2.13']],
                     'type': 'list',
-                    'options': {'md5s': {'v_range': [['6.2.0', '6.2.12']], 'type': 'raw'}, 'name': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'}},
+                    'options': {'md5s': {'v_range': [['6.2.0', '6.2.13']], 'type': 'raw'}, 'name': {'v_range': [['6.2.0', '6.2.13']], 'type': 'str'}},
                     'elements': 'dict'
                 },
-                'name': {'v_range': [['6.2.0', '6.2.12']], 'required': True, 'type': 'str'}
+                'name': {'v_range': [['6.2.0', '6.2.13']], 'required': True, 'type': 'str'}
             }
-
         }
     }
 
@@ -223,17 +214,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'vpnsslweb_virtualdesktopapplist'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
